import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/layout'
import {routerMode} from '@/config/index'
import store from '@/store/index'

Vue.use(VueRouter)

/**
 * 静态路由
 * @type {({path: string, component: (function(): *), hidden: boolean}|{path: string, component: (function(): *), hidden: boolean, name: string}|{path: string, component: (function(): *), hidden: boolean, name: string})[]}
 */
export const currencyRoutes = [
	{
		path: '/login',
		component: () =>
			import(/* webpackChunkName: "login" */ '@/views/login/index.vue'),
		hidden: true
	},
	{
		path: '/401',
		name: '401',
		component: () => import('@/views/401'),
		hidden: true
	},
	{
		path: '/404',
		name: '404',
		component: () => import('@/views/404'),
		hidden: true
	}
]

/**
 * 动态路由
 * @type {any}
 */
export const routes = [
	{
		path: '/',
		name: 'Company',
		component: Layout,
		redirect: '/company',
		meta: {
			icon: 'el-icon-office-building',
			title: '企业管理'
		},
		children: [{
			path: '/',
			name: 'CompanyInformation',
			component: () =>
				import('@/views/dashboard/index.vue'),
			meta: {
				title: '企业信息',
				icon: 'el-icon-s-data'
			}
		}]
	}
]

const router = new VueRouter({
	base: '',
	mode: routerMode,
	scrollBehavior: () => ({
		y: 0
	}),
	routes: currencyRoutes
})

// 解决addRoute不能删除动态路由问题
export function resetRouter() {
	router.matcher = new VueRouter({
		base: '',
		mode: routerMode,
		scrollBehavior: () => ({
			y: 0
		}),
		routes: currencyRoutes
	}).matcher
}

// 导航守卫  验证是否登录了  没有登录跳转到登录页面
router.beforeEach(async (to, from, next) => {
	if (to.path === '/login') {
		next()
	} else {
		const token = store.getters['user/token']
		const hasRoles = store.getters['user/roles']
		console.log(hasRoles)
		if (token) {
			if (hasRoles.length <= 0) {
				try {
					const {roles} = await store.dispatch('user/getRoutes')
					console.log(roles)
					const addRoutes = await store.dispatch('routes/getAsyncRoutes')
					router.addRoutes(addRoutes)
					next({...to, replace: true})
				} catch (error) {
					console.info(error)
					console.log('此路不通')
				}
			} else {
				next()
			}
		} else {
			next({
				path: '/login'
			})
		}
	}
})

export default router
