/**
 * @author yh
 * @description 所有全局配置的状态管理，如无必要请勿修改
 */

const state = {
  layout: "vertical", // horizontal 横向布局  vertical 纵向布局
  themeStyle: "default",
  header: "fixed",
  tabsBar: false,
  collapse: false
};

const getters = {
  layout: state => state.layout,
  themeStyle: state => state.themeStyle,
  header: state => state.header,
  tabsBar: state => state.tabsBar,
  collapse: state => state.collapse
};

const mutations = {
  changeLayout: (state, layout) => {
    if (layout) state.layout = layout;
  },
  changeThemeStyle: (state, style) => {
    if (style) state.themeStyle = style;
  },
  changeHeader: (state, header) => {
    if (header) state.header = header;
  },
  changeTabsBar: (state, tabsBar) => {
    if (tabsBar) state.tabsBar = tabsBar;
  },
  changeCollapse: state => {
    state.collapse = !state.collapse;
  }
};

const actions = {
  changeLayout({ commit }, layout) {
    commit("changeLayout", layout);
  },
  changeThemeStyle({ commit }, style) {
    commit("changeThemeStyle", style);
  },
  changeHeader({ commit }, header) {
    commit("changeHeader", header);
  },
  changeTabsBar({ commit }, tabsBar) {
    commit("changeTabsBar", tabsBar);
  },
  changeCollapse({ commit }) {
    commit("changeCollapse");
  }
};

export default { namespaced: true, state, getters, mutations, actions };
