/**
 * @author yh
 * @description 用户的状态管理
 */
import router, { resetRouter } from "@/router/index";
import { getAppCode, keepTokenTime, getUserInfo } from "@/api/account";
import axios from "axios";

const state = {
  code: sessionStorage.getItem("code") ? sessionStorage.getItem("code") : "", //  平台code
  token: sessionStorage.getItem("token") ? sessionStorage.getItem("token") : "", // 认证凭证
  platformId: sessionStorage.getItem("platformId")
    ? sessionStorage.getItem("platformId")
    : "", // 认证凭证
  userInfo: sessionStorage.getItem("userInfo") || "", // 用户信息
  roles: [],
  transportId: sessionStorage.getItem("transportId")
    ? sessionStorage.getItem("transportId")
    : "",
  areaCode: sessionStorage.getItem("areaCode")
    ? sessionStorage.getItem("areaCode")
    : "" // 当前区域code
};

const getters = {
  code: state => state.code,
  token: state => state.token,
  platformId: state => state.platformId,
  roles: state => state.roles,
  transportId: state => state.transportId,
  areaCode: state => state.areaCode,
  userInfo: state => (state.userInfo ? JSON.parse(state.userInfo) : "")
};

const mutations = {
  SET_CODE(state, val) {
    state.code = val;
    sessionStorage.setItem("code", val);
  },
  SET_PLATFORMID(state, val) {
    state.platformId = val;
    sessionStorage.setItem("platformId", val);
  },
  SET_TOKEN(state, val) {
    state.token = val;
    sessionStorage.setItem("token", val);
  },
  DEL_TOKEN(state) {
    state.token = "";
    state.roles = [];
    state.areaCode = "";
    sessionStorage.removeItem("token");
  },
  SET_ROLES(state, payload) {
    state.roles = payload;
  },
  SET_USERINFO(state, val) {
    sessionStorage.setItem("userInfo", val);
    state.userInfo = val;
  },
  CLEAR_LOGIN(state) {
    sessionStorage.removeItem("user");
    sessionStorage.removeItem("userInfo");
    sessionStorage.removeItem("token");
    state.roles = [];
  },
  SET_TRANSPORTID(state, val) {
    state.transportId = val;
    sessionStorage.setItem("transportId", val);
  },
  SET_AREACODE(state, val) {
    state.areaCode = val;
    sessionStorage.setItem("areaCode", val);
  }
};

const actions = {
  updateAreaCode({ commit }, code) {
    commit("SET_AREACODE", code);
  },
  loginOut({ commit }) {
    commit("DEL_TOKEN");
    sessionStorage.removeItem("clientId");
    commit("SET_TRANSPORTID", "");
    resetRouter();
    router.push({
      path: "/login",
      query: {
        redirect: "/"
      }
    });
  },
  getUserInfo({ commit }) {
    return new Promise((resolve, reject) => {
      getUserInfo()
        .then(res => {
          commit("SET_USERINFO", res.data);
          resolve(res.data);
        })
        .catch(err => {
          reject(err);
        });
    });
  },
  PlatformCode({ commit }) {
    return new Promise((resolve, reject) => {
      getAppCode()
        .then(res => {
          axios.defaults.headers.XOADOAPPACCESSCODE = res;
          commit("SET_CODE", res);
          resolve(res);
        })
        .catch(err => {
          reject(err);
        });
    });
  },
  _keepTokenTime({ commit, rootGetters }) {
    return new Promise((resolve, reject) => {
      let _token = rootGetters.token;
      keepTokenTime({ tokenId: _token })
        .then(res => {
          if (res.status == 200) {
            commit("SET_TOKEN", res.data);
          }
          resolve(res);
        })
        .catch(err => {
          reject(err);
        });
    });
  },
  getRoutes({ commit, getters }) {
    return new Promise(resolve => {
      setTimeout(() => {
        console.log("获取用户对应权限路由成功");
        let datas = {};
        let userInfo = getters.userInfo;
        datas = {
          name: userInfo.name,
          roles: [
            "ChangeAndPut",
            "changeAndPut",
            "Complain",
            "complain",
            "EnteringOrder",
            "enteringOrder",
            "ShareTheBill",
            "shareTheBill",
            "Waybill",
            "waybill",
            "Order"
          ]
        };
        const { roles } = datas;
        commit("SET_ROLES", roles);
        resolve(datas);
      }, 200);
    });
  }
};

export default { namespaced: true, state, getters, mutations, actions };
